@@ -5,7 +5,7 @@ use warnings;
 use vars qw[$VERSION %utilities];
 use Module::CoreList;
 
-$VERSION = '5.20170923';
+$VERSION = '5.20171020';
 
 sub utilities {
     my $perl = shift;
@@ -1326,6 +1326,13 @@ my %delta = (
         removed => {
         }
     },
+    5.027005 => {
+        delta_from => 5.027004,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
